@@ -492,6 +492,7 @@ command_entry_update_color(void)
     
     /* change widget style */
     /* style = malloc(sizeof(Gtk_style)); */
+    gtk_widget_ensure_style(entry_command);
     style = gtk_style_copy(gtk_widget_get_style(entry_command));
     
     style->fg[GTK_STATE_NORMAL].red = (gushort) prop.cmd_line_color_fg_r;
@@ -535,7 +536,8 @@ history_auto_complete(GtkWidget *widget, GdkEventKey *event)
     gchar* completed_command;
     int i;
 
-    sprintf(current_command, "%s%s", gtk_entry_get_text(GTK_ENTRY(widget)), event->string); 
+    g_snprintf(current_command, sizeof(current_command), "%s%s", 
+	       gtk_entry_get_text(GTK_ENTRY(widget)), event->string); 
     for(i = LENGTH_HISTORY_LIST - 1; i >= 0; i--) 
   	{
 	    if(!exists_history_entry(i))
