@@ -59,6 +59,9 @@
 #elif HAVE_SUN_AUDIOIO_H
 #include <sun/audioio.h>
 #define SUN_API
+#elif HAVE_DMEDIA_AUDIO_H
+#define IRIX_API
+#include <dmedia/audio.h>
 #else
 #error No soundcard defenition!
 #endif /* SOUNDCARD_H */
@@ -69,6 +72,9 @@
 #ifdef SUN_API
 #define VOLUME_MAX 255
 #endif
+#ifdef IRIX_API
+#define VOLUME_MAX 255
+#endif
 
 #include "lamp-small.xpm"
 #include "lamp-small-red.xpm"
@@ -112,6 +118,21 @@ MixerData *md = NULL;
 
 gint mixerfd = -1;
 
+#ifdef OSS_API
+static int mixerchannel;
+#endif
+
+#ifdef IRIX_API
+/*
+ * Note: we are using the obsolete API to increase portability.
+ * /usr/sbin/audiopanel provides many more options...
+ */
+#define MAX_PV_BUF	4
+long pv_buf[MAX_PV_BUF] = { 
+  AL_LEFT_SPEAKER_GAIN, 0L, AL_RIGHT_SPEAKER_GAIN, 0L 
+};
+#endif
+
 /********************** Mixer related Code *******************/
 /*  Mostly based on the gmix code                            */
 /*************************************************************/
@@ -120,10 +141,20 @@ openMixer( gchar *device_name )
 {
 	gint res, ver;
 #ifdef OSS_API
+	int devmask;
+
 	mixerfd = open(device_name, O_RDWR, 0);
 #endif
 #ifdef SUN_API
 	mixerfd = open(device_name, AUDIO_GETINFO, O_WRONLY);
+#endif
+#ifdef IRIX_API
+	/* 
+	 * This is a result code, not a file descriptor, and we ignore
+	 * the values read.  But the call is useful to see if we can
+	 * access the default output port.
+	 */
+	mixerfd = ALgetparams(AL_DEFAULT_DEVICE, pv_buf, MAX_PV_BUF);
 #endif
 	if (mixerfd < 0) {
 		/* probably should die more gracefully */
@@ -145,6 +176,29 @@ openMixer( gchar *device_name )
 			"with a different version of\nsoundcard.h.\n"));
         }
 #endif
+#ifdef OSS_API
+	/*
+	 * Check whether this mixer actually supports the channel
+	 * we're going to try to monitor.
+	 */
+	res = ioctl(mixerfd, MIXER_READ(SOUND_MIXER_DEVMASK), &devmask);
+	if (res != 0) {
+		char *s = g_strdup_printf(_("Querying available channels of mixer device %s failed\n"), device_name);
+		gnome_error_dialog(s);
+		g_free(s);
+		return;
+	} else if (devmask & SOUND_MASK_VOLUME) {
+		mixerchannel = SOUND_MIXER_VOLUME;
+	} else if (devmask & SOUND_MASK_PCM) {
+		g_message(_("warning: mixer has no volume channel - using PCM instead.\n"));
+		mixerchannel = SOUND_MIXER_PCM;
+	} else {
+		char *s = g_strdup_printf(_("Mixer device %s has neither volume nor PCM channels.\n"), device_name);
+		gnome_error_dialog(s);
+		g_free(s);
+		return;
+	}
+#endif		
 }
 
 /* only works with master vol currently */
@@ -156,7 +210,7 @@ readMixer(void)
 	/* if we couldn't open the mixer */
 	if (mixerfd < 0) return 0;
 
-	ioctl(mixerfd, MIXER_READ(SOUND_MIXER_VOLUME), &vol);
+	ioctl(mixerfd, MIXER_READ(mixerchannel), &vol);
 
 	l = vol & 0xff;
 	r = (vol & 0xff00) >> 8;
@@ -170,6 +224,14 @@ readMixer(void)
  	ioctl (mixerfd, AUDIO_GETINFO, &ainfo);
  	return (ainfo.play.gain);
 #endif
+#ifdef IRIX_API
+	/*
+	 * Average the current gain settings.  If we can't read the
+	 * current levels use the values from the previous read.
+	 */
+	(void) ALgetparams(AL_DEFAULT_DEVICE, pv_buf, MAX_PV_BUF);
+	return (pv_buf[1] + pv_buf[3]) / 2;
+#endif
 }
 
 static void
@@ -182,7 +244,8 @@ setMixer(gint vol)
 
 	tvol = (vol << 8) + vol;
 /*g_message("Saving mixer value of %d",tvol);*/
-	ioctl(mixerfd, MIXER_WRITE(SOUND_MIXER_VOLUME), &tvol);
+	ioctl(mixerfd, MIXER_WRITE(mixerchannel), &tvol);
+	ioctl(mixerfd, MIXER_WRITE(SOUND_MIXER_SPEAKER), &tvol);
 #endif
 #ifdef SUN_API
  	audio_info_t ainfo;
@@ -190,6 +253,17 @@ setMixer(gint vol)
  	ainfo.play.gain = vol;
  	ioctl (mixerfd, AUDIO_SETINFO, &ainfo);
 #endif
+#ifdef IRIX_API
+	if (vol < 0) 
+	  tvol = 0;
+	else if (vol > VOLUME_MAX)
+	  tvol = VOLUME_MAX;
+	else
+	  tvol = vol;
+
+	pv_buf[1] = pv_buf[3] = tvol;
+	(void) ALsetparams(AL_DEFAULT_DEVICE, pv_buf, MAX_PV_BUF);
+#endif
 }
 
 static void
@@ -404,9 +478,9 @@ create_computer_mixer_widget(GtkWidget ** mixer,
 	hscale = hslider_new();
 	
         hadj=(GtkAdjustment *) gtk_adjustment_new (-50, -VOLUME_MAX, 0.0, 
-					50.0, 25.0, 0.0);
+					VOLUME_MAX/100, VOLUME_MAX/10, 0.0);
         vadj=(GtkAdjustment *) gtk_adjustment_new (-50, -VOLUME_MAX, 0.0, 
-					50.0, 25.0, 0.0);
+					VOLUME_MAX/100, VOLUME_MAX/10, 0.0);
 
 	hlightwid = gnome_pixmap_new_from_xpm_d(lamp_small_xpm);
 	vlightwid = gnome_pixmap_new_from_xpm_d(lamp_small_xpm);
